@@ -13,9 +13,8 @@ use Exporter;
 use parent 'Exporter';
 
 #设备版本信息和默认导出函数
-our $VERSION = 0.07;
-our @EXPORT
-    = qw 'ip_info info_parser device_arp device_mac device_nei device_eth device_info';
+our $VERSION = 0.08;
+our @EXPORT  = qw 'ip_info info_parser device_arp device_mac device_nei device_eth device_info';
 
 #------------------------------------------------------------------------------
 # 常量 ip_str mac_str 数据格式
@@ -184,18 +183,17 @@ sub ip_info {
                     foreach my $member ( @{$eth_member} ) {
 
                         #获取当前接口的邻居设备，输出为邻居设备名
-                        my $device_nei
-                            = $nei_info->{$device}{$member}{"neighbor"};
+                        my $device_nei = $nei_info->{$device}{$member}{"neighbor"};
 
                         #判断是否为 ipPhone
                         if ( $device_nei =~ /eSpace/i ) {
 
                             #如果命中IP电话，将解析到的结果写入数据结构
-                            $ret4->{$ip_info}{"location"}  = $device_location;
-                            $ret4->{$ip_info}{"hostname"}  = $device;
-                            $ret4->{$ip_info}{"interface"} = $member;
-                            $ret4->{$ip_info}{"mac"}       = $mac;
-                            $ret4->{$ip_info}{"vlan"}      = $vlan;
+                            $ret4->{$ip_info}{"location"}     = $device_location;
+                            $ret4->{$ip_info}{"hostname"}     = $device;
+                            $ret4->{$ip_info}{"interface"}    = $member;
+                            $ret4->{$ip_info}{"mac"}          = $mac;
+                            $ret4->{$ip_info}{"vlan"}         = $vlan;
                             $ret4->{$ip_info}{"vpn_instance"} = $vpn_instance;
                             $ret4->{$ip_info}{"gate_device"}  = $device;
 
@@ -236,56 +234,41 @@ sub ip_info {
                                     {
 
                                         #将解析到的结果写入数据结构
-                                        $ret5->{$ip_info}{"location"}
-                                            = $nei_location;
-                                        $ret5->{$ip_info}{"hostname"}
-                                            = $device_nei;
-                                        $ret5->{$ip_info}{"vlan"} = $mac_vlan;
-                                        $ret5->{$ip_info}{"mac"}  = $mac;
-                                        $ret5->{$ip_info}{"interface"}
-                                            = $nei_interface;
-                                        $ret5->{$ip_info}{"vpn_instance"}
-                                            = $vpn_instance;
-                                        $ret5->{$ip_info}{"gate_device"}
-                                            = $device;
+                                        $ret5->{$ip_info}{"location"}     = $nei_location;
+                                        $ret5->{$ip_info}{"hostname"}     = $device_nei;
+                                        $ret5->{$ip_info}{"vlan"}         = $mac_vlan;
+                                        $ret5->{$ip_info}{"mac"}          = $mac;
+                                        $ret5->{$ip_info}{"interface"}    = $nei_interface;
+                                        $ret5->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                        $ret5->{$ip_info}{"gate_device"}  = $device;
                                     }
 
-                                   #判断MAC地址是否为 静态绑定 sticky
+                                    #判断MAC地址是否为 静态绑定 sticky
                                     elsif ($mac_type =~ /sticky/
                                         && $mac eq $mac_rev )
                                     {
 
                                         #将解析到的结果写入数据结构
-                                        $ret4->{$ip_info}{"location"}
-                                            = $nei_location;
-                                        $ret4->{$ip_info}{"hostname"}
-                                            = $device_nei;
-                                        $ret4->{$ip_info}{"interface"}
-                                            = $nei_interface;
-                                        $ret4->{$ip_info}{"mac"}  = $mac;
-                                        $ret4->{$ip_info}{"vlan"} = $mac_vlan;
-                                        $ret4->{$ip_info}{"vpn_instance"}
-                                            = $vpn_instance;
-                                        $ret4->{$ip_info}{"gate_device"}
-                                            = $device;
+                                        $ret4->{$ip_info}{"location"}     = $nei_location;
+                                        $ret4->{$ip_info}{"hostname"}     = $device_nei;
+                                        $ret4->{$ip_info}{"interface"}    = $nei_interface;
+                                        $ret4->{$ip_info}{"mac"}          = $mac;
+                                        $ret4->{$ip_info}{"vlan"}         = $mac_vlan;
+                                        $ret4->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                        $ret4->{$ip_info}{"gate_device"}  = $device;
                                     }
 
                                     #进行逻辑判断，是否匹配当前ARP表项
                                     elsif ( $mac eq $mac_rev ) {
 
                                         #将解析到的结果写入数据结构
-                                        $ret2->{$ip_info}{"location"}
-                                            = $nei_location;
-                                        $ret2->{$ip_info}{"hostname"}
-                                            = $device_nei;
-                                        $ret2->{$ip_info}{"vlan"} = $mac_vlan;
-                                        $ret2->{$ip_info}{"mac"}  = $mac;
-                                        $ret2->{$ip_info}{"interface"}
-                                            = $nei_interface;
-                                        $ret2->{$ip_info}{"vpn_instance"}
-                                            = $vpn_instance;
-                                        $ret2->{$ip_info}{"gate_device"}
-                                            = $device;
+                                        $ret2->{$ip_info}{"location"}     = $nei_location;
+                                        $ret2->{$ip_info}{"hostname"}     = $device_nei;
+                                        $ret2->{$ip_info}{"vlan"}         = $mac_vlan;
+                                        $ret2->{$ip_info}{"mac"}          = $mac;
+                                        $ret2->{$ip_info}{"interface"}    = $nei_interface;
+                                        $ret2->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                        $ret2->{$ip_info}{"gate_device"}  = $device;
                                     }
                                 }
                             }
@@ -297,7 +280,7 @@ sub ip_info {
                             #查找设备本身ETH-TRUNK下的接口MAC
                             my $dev_mac = $mac_info->{$device};
 
-                            #遍历设备本身的MAC地址信息，寻找能与当前ARP配对接口
+                           #遍历设备本身的MAC地址信息，寻找能与当前ARP配对接口
                             foreach my $dev_interface ( keys %{$dev_mac} ) {
 
                                 #获取当前邻居的MAC地址表
@@ -321,17 +304,13 @@ sub ip_info {
                                     {
 
                                         #将解析到的结果写入数据结构
-                                        $ret5->{$ip_info}{"location"}
-                                            = $device_location;
-                                        $ret5->{$ip_info}{"hostname"} = $device;
-                                        $ret5->{$ip_info}{"vlan"} = $mac_vlan;
-                                        $ret5->{$ip_info}{"mac"}  = $mac;
-                                        $ret5->{$ip_info}{"interface"}
-                                            = $dev_interface;
-                                        $ret5->{$ip_info}{"vpn_instance"}
-                                            = $vpn_instance;
-                                        $ret5->{$ip_info}{"gate_device"}
-                                            = $device;
+                                        $ret5->{$ip_info}{"location"}     = $device_location;
+                                        $ret5->{$ip_info}{"hostname"}     = $device;
+                                        $ret5->{$ip_info}{"vlan"}         = $mac_vlan;
+                                        $ret5->{$ip_info}{"mac"}          = $mac;
+                                        $ret5->{$ip_info}{"interface"}    = $dev_interface;
+                                        $ret5->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                        $ret5->{$ip_info}{"gate_device"}  = $device;
                                     }
 
                                     #判断MAC地址是否为 静态绑定 sticky
@@ -340,34 +319,26 @@ sub ip_info {
                                     {
 
                                         #将解析到的结果写入数据结构
-                                        $ret4->{$ip_info}{"location"}
-                                            = $device_location;
-                                        $ret4->{$ip_info}{"hostname"} = $device;
-                                        $ret4->{$ip_info}{"vlan"} = $mac_vlan;
-                                        $ret4->{$ip_info}{"mac"}  = $mac;
-                                        $ret4->{$ip_info}{"interface"}
-                                            = $dev_interface;
-                                        $ret4->{$ip_info}{"vpn_instance"}
-                                            = $vpn_instance;
-                                        $ret4->{$ip_info}{"gate_device"}
-                                            = $device;
+                                        $ret4->{$ip_info}{"location"}     = $device_location;
+                                        $ret4->{$ip_info}{"hostname"}     = $device;
+                                        $ret4->{$ip_info}{"vlan"}         = $mac_vlan;
+                                        $ret4->{$ip_info}{"mac"}          = $mac;
+                                        $ret4->{$ip_info}{"interface"}    = $dev_interface;
+                                        $ret4->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                        $ret4->{$ip_info}{"gate_device"}  = $device;
                                     }
 
                                     #进行逻辑判断，是否匹配当前ARP表项
                                     elsif ( $mac eq $mac_rev ) {
 
                                         #将解析到的结果写入数据结构
-                                        $ret2->{$ip_info}{"location"}
-                                            = $device_location;
-                                        $ret2->{$ip_info}{"hostname"} = $device;
-                                        $ret2->{$ip_info}{"vlan"} = $mac_vlan;
-                                        $ret2->{$ip_info}{"mac"}  = $mac;
-                                        $ret2->{$ip_info}{"interface"}
-                                            = $dev_interface;
-                                        $ret2->{$ip_info}{"vpn_instance"}
-                                            = $vpn_instance;
-                                        $ret2->{$ip_info}{"gate_device"}
-                                            = $device;
+                                        $ret2->{$ip_info}{"location"}     = $device_location;
+                                        $ret2->{$ip_info}{"hostname"}     = $device;
+                                        $ret2->{$ip_info}{"vlan"}         = $mac_vlan;
+                                        $ret2->{$ip_info}{"mac"}          = $mac;
+                                        $ret2->{$ip_info}{"interface"}    = $dev_interface;
+                                        $ret2->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                        $ret2->{$ip_info}{"gate_device"}  = $device;
                                     }
                                 }
                             }
@@ -382,13 +353,12 @@ sub ip_info {
                     $self_interface =~ s/\.\d+$//;
 
                     #获取当前接口的邻居设备，输出为邻居设备名
-                    my $device_nei
-                        = $nei_info->{$device}{$self_interface}{"neighbor"};
+                    my $device_nei = $nei_info->{$device}{$self_interface}{"neighbor"};
 
                     #判断是否为 ipPhone
                     if ( $device_nei =~ /eSpace/i ) {
 
-                         #如果命中IP电话，将解析到的结果写入数据结构
+                        #如果命中IP电话，将解析到的结果写入数据结构
                         $ret4->{$ip_info}{"location"}     = $device_location;
                         $ret4->{$ip_info}{"hostname"}     = $device;
                         $ret4->{$ip_info}{"interface"}    = $self_interface;
@@ -434,16 +404,13 @@ sub ip_info {
                                 {
 
                                     #将解析到的结果写入数据结构
-                                    $ret5->{$ip_info}{"location"}
-                                        = $nei_location;
-                                    $ret5->{$ip_info}{"hostname"} = $device_nei;
-                                    $ret5->{$ip_info}{"interface"}
-                                        = $nei_interface;
-                                    $ret5->{$ip_info}{"mac"}  = $mac;
-                                    $ret5->{$ip_info}{"vlan"} = $mac_vlan;
-                                    $ret5->{$ip_info}{"vpn_instance"}
-                                        = $vpn_instance;
-                                    $ret5->{$ip_info}{"gate_device"} = $device;
+                                    $ret5->{$ip_info}{"location"}     = $nei_location;
+                                    $ret5->{$ip_info}{"hostname"}     = $device_nei;
+                                    $ret5->{$ip_info}{"interface"}    = $nei_interface;
+                                    $ret5->{$ip_info}{"mac"}          = $mac;
+                                    $ret5->{$ip_info}{"vlan"}         = $mac_vlan;
+                                    $ret5->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                    $ret5->{$ip_info}{"gate_device"}  = $device;
                                 }
 
                                 #判断MAC地址是否为 静态绑定 sticky
@@ -452,32 +419,26 @@ sub ip_info {
                                 {
 
                                     #将解析到的结果写入数据结构
-                                    $ret4->{$ip_info}{"location"}
-                                        = $nei_location;
-                                    $ret4->{$ip_info}{"hostname"} = $device_nei;
-                                    $ret4->{$ip_info}{"interface"}
-                                        = $nei_interface;
-                                    $ret4->{$ip_info}{"mac"}  = $mac;
-                                    $ret4->{$ip_info}{"vlan"} = $mac_vlan;
-                                    $ret4->{$ip_info}{"vpn_instance"}
-                                        = $vpn_instance;
-                                    $ret4->{$ip_info}{"gate_device"} = $device;
+                                    $ret4->{$ip_info}{"location"}     = $nei_location;
+                                    $ret4->{$ip_info}{"hostname"}     = $device_nei;
+                                    $ret4->{$ip_info}{"interface"}    = $nei_interface;
+                                    $ret4->{$ip_info}{"mac"}          = $mac;
+                                    $ret4->{$ip_info}{"vlan"}         = $mac_vlan;
+                                    $ret4->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                    $ret4->{$ip_info}{"gate_device"}  = $device;
                                 }
 
-                               #进行逻辑判断，是否匹配当前ARP表项
+                                #进行逻辑判断，是否匹配当前ARP表项
                                 elsif ( $mac eq $mac_rev ) {
 
                                     #将解析到的结果写入数据结构
-                                    $ret2->{$ip_info}{"location"}
-                                        = $nei_location;
-                                    $ret2->{$ip_info}{"hostname"} = $device_nei;
-                                    $ret2->{$ip_info}{"interface"}
-                                        = $nei_interface;
-                                    $ret2->{$ip_info}{"mac"}  = $mac;
-                                    $ret2->{$ip_info}{"vlan"} = $mac_vlan;
-                                    $ret2->{$ip_info}{"vpn_instance"}
-                                        = $vpn_instance;
-                                    $ret2->{$ip_info}{"gate_device"} = $device;
+                                    $ret2->{$ip_info}{"location"}     = $nei_location;
+                                    $ret2->{$ip_info}{"hostname"}     = $device_nei;
+                                    $ret2->{$ip_info}{"interface"}    = $nei_interface;
+                                    $ret2->{$ip_info}{"mac"}          = $mac;
+                                    $ret2->{$ip_info}{"vlan"}         = $mac_vlan;
+                                    $ret2->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                    $ret2->{$ip_info}{"gate_device"}  = $device;
                                 }
                             }
                         }
@@ -513,16 +474,13 @@ sub ip_info {
                                 {
 
                                     #将解析到的结果写入数据结构
-                                    $ret5->{$ip_info}{"location"}
-                                        = $device_location;
-                                    $ret5->{$ip_info}{"hostname"} = $device;
-                                    $ret5->{$ip_info}{"vlan"}     = $mac_vlan;
-                                    $ret5->{$ip_info}{"mac"}      = $mac;
-                                    $ret5->{$ip_info}{"interface"}
-                                        = $dev_interface;
-                                    $ret5->{$ip_info}{"vpn_instance"}
-                                        = $vpn_instance;
-                                    $ret5->{$ip_info}{"gate_device"} = $device;
+                                    $ret5->{$ip_info}{"location"}     = $device_location;
+                                    $ret5->{$ip_info}{"hostname"}     = $device;
+                                    $ret5->{$ip_info}{"vlan"}         = $mac_vlan;
+                                    $ret5->{$ip_info}{"mac"}          = $mac;
+                                    $ret5->{$ip_info}{"interface"}    = $dev_interface;
+                                    $ret5->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                    $ret5->{$ip_info}{"gate_device"}  = $device;
                                 }
 
                                 #判断MAC地址是否为 静态绑定 sticky
@@ -531,32 +489,26 @@ sub ip_info {
                                 {
 
                                     #将解析到的结果写入数据结构
-                                    $ret4->{$ip_info}{"location"}
-                                        = $device_location;
-                                    $ret4->{$ip_info}{"hostname"} = $device;
-                                    $ret4->{$ip_info}{"vlan"}     = $mac_vlan;
-                                    $ret4->{$ip_info}{"mac"}      = $mac;
-                                    $ret4->{$ip_info}{"interface"}
-                                        = $dev_interface;
-                                    $ret4->{$ip_info}{"vpn_instance"}
-                                        = $vpn_instance;
-                                    $ret4->{$ip_info}{"gate_device"} = $device;
+                                    $ret4->{$ip_info}{"location"}     = $device_location;
+                                    $ret4->{$ip_info}{"hostname"}     = $device;
+                                    $ret4->{$ip_info}{"vlan"}         = $mac_vlan;
+                                    $ret4->{$ip_info}{"mac"}          = $mac;
+                                    $ret4->{$ip_info}{"interface"}    = $dev_interface;
+                                    $ret4->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                    $ret4->{$ip_info}{"gate_device"}  = $device;
                                 }
 
                                 #进行逻辑判断，是否匹配当前ARP表项
                                 elsif ( $mac eq $mac_rev ) {
 
                                     #将解析到的结果写入数据结构
-                                    $ret2->{$ip_info}{"location"}
-                                        = $device_location;
-                                    $ret2->{$ip_info}{"hostname"} = $device;
-                                    $ret2->{$ip_info}{"vlan"}     = $mac_vlan;
-                                    $ret2->{$ip_info}{"mac"}      = $mac;
-                                    $ret2->{$ip_info}{"interface"}
-                                        = $dev_interface;
-                                    $ret2->{$ip_info}{"vpn_instance"}
-                                        = $vpn_instance;
-                                    $ret2->{$ip_info}{"gate_device"} = $device;
+                                    $ret2->{$ip_info}{"location"}     = $device_location;
+                                    $ret2->{$ip_info}{"hostname"}     = $device;
+                                    $ret2->{$ip_info}{"vlan"}         = $mac_vlan;
+                                    $ret2->{$ip_info}{"mac"}          = $mac;
+                                    $ret2->{$ip_info}{"interface"}    = $dev_interface;
+                                    $ret2->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                    $ret2->{$ip_info}{"gate_device"}  = $device;
                                 }
                             }
                         }
@@ -588,15 +540,13 @@ sub ip_info {
                             if ( $mac_type =~ /authen/ && $mac eq $mac_rev ) {
 
                                 #将解析到的结果写入数据结构
-                                $ret5->{$ip_info}{"location"}
-                                    = $device_location;
-                                $ret5->{$ip_info}{"hostname"}  = $device;
-                                $ret5->{$ip_info}{"interface"} = $dev_interface;
-                                $ret5->{$ip_info}{"mac"}       = $mac;
-                                $ret5->{$ip_info}{"vlan"}      = $mac_vlan;
-                                $ret5->{$ip_info}{"vpn_instance"}
-                                    = $vpn_instance;
-                                $ret5->{$ip_info}{"gate_device"} = $device;
+                                $ret5->{$ip_info}{"location"}     = $device_location;
+                                $ret5->{$ip_info}{"hostname"}     = $device;
+                                $ret5->{$ip_info}{"interface"}    = $dev_interface;
+                                $ret5->{$ip_info}{"mac"}          = $mac;
+                                $ret5->{$ip_info}{"vlan"}         = $mac_vlan;
+                                $ret5->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                $ret5->{$ip_info}{"gate_device"}  = $device;
                             }
 
                             #判断MAC地址是否为 静态绑定 sticky
@@ -605,30 +555,26 @@ sub ip_info {
                             {
 
                                 #将解析到的结果写入数据结构
-                                $ret4->{$ip_info}{"location"}
-                                    = $device_location;
-                                $ret4->{$ip_info}{"hostname"}  = $device;
-                                $ret4->{$ip_info}{"interface"} = $dev_interface;
-                                $ret4->{$ip_info}{"mac"}       = $mac;
-                                $ret4->{$ip_info}{"vlan"}      = $mac_vlan;
-                                $ret4->{$ip_info}{"vpn_instance"}
-                                    = $vpn_instance;
-                                $ret4->{$ip_info}{"gate_device"} = $device;
+                                $ret4->{$ip_info}{"location"}     = $device_location;
+                                $ret4->{$ip_info}{"hostname"}     = $device;
+                                $ret4->{$ip_info}{"interface"}    = $dev_interface;
+                                $ret4->{$ip_info}{"mac"}          = $mac;
+                                $ret4->{$ip_info}{"vlan"}         = $mac_vlan;
+                                $ret4->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                $ret4->{$ip_info}{"gate_device"}  = $device;
                             }
 
                             #进行逻辑判断，是否匹配当前ARP表项
                             elsif ( $mac eq $mac_rev ) {
 
                                 #将解析到的结果写入数据结构
-                                $ret2->{$ip_info}{"location"}
-                                    = $device_location;
-                                $ret2->{$ip_info}{"hostname"}  = $device;
-                                $ret2->{$ip_info}{"interface"} = $dev_interface;
-                                $ret2->{$ip_info}{"mac"}       = $mac;
-                                $ret2->{$ip_info}{"vlan"}      = $mac_vlan;
-                                $ret2->{$ip_info}{"vpn_instance"}
-                                    = $vpn_instance;
-                                $ret2->{$ip_info}{"gate_device"} = $device;
+                                $ret2->{$ip_info}{"location"}     = $device_location;
+                                $ret2->{$ip_info}{"hostname"}     = $device;
+                                $ret2->{$ip_info}{"interface"}    = $dev_interface;
+                                $ret2->{$ip_info}{"mac"}          = $mac;
+                                $ret2->{$ip_info}{"vlan"}         = $mac_vlan;
+                                $ret2->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                $ret2->{$ip_info}{"gate_device"}  = $device;
                             }
                         }
                     }
@@ -799,7 +745,7 @@ sub device_arp {
         #优先匹配较早版本的ARP格式
         if ( $cli
             =~ /^(?<ipaddr>(\d{1,3}\.){3}(\d{1,3}))\s+(?<mac>([0-9a-fA-F]{4}\-){2}[0-9a-fA-F]{4})\s+((?<exp_time>\d+)\s+)?(?<type>(I\s\-|D\-\d+))(\s+(?<interface>.*?))(\s+(?<vpn_instance>.*?))?$/
-            )
+          )
         {
             #获取解析结果
             my $mac          = $+{mac};
@@ -812,15 +758,12 @@ sub device_arp {
             if ( $mac =~ /Incomplete/i ) {
 
                 #封装特定的数据结构
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"ipaddr"} = $ipaddr;
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"mac"} = "Incomplete";
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"exp_time"}
-                    = $exp_time || "forever";
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"vlan"} = undef;
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"interface"}
-                    = $interface;
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"vpn_instance"}
-                    = $vpn_instance;
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"ipaddr"}       = $ipaddr;
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"mac"}          = "Incomplete";
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"exp_time"}     = $exp_time || "forever";
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"vlan"}         = undef;
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"interface"}    = $interface;
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"vpn_instance"} = $vpn_instance;
 
                 #继续下一个迭代
                 next;
@@ -842,10 +785,9 @@ sub device_arp {
             }
 
             #输出解析结果
-            $ret->{$type}{$interface}{$ipaddr}{"ipaddr"} = $ipaddr;
-            $ret->{$type}{$interface}{$ipaddr}{"mac"}    = $mac;
-            $ret->{$type}{$interface}{$ipaddr}{"exp_time"}
-                = $exp_time || "forever";
+            $ret->{$type}{$interface}{$ipaddr}{"ipaddr"}       = $ipaddr;
+            $ret->{$type}{$interface}{$ipaddr}{"mac"}          = $mac;
+            $ret->{$type}{$interface}{$ipaddr}{"exp_time"}     = $exp_time || "forever";
             $ret->{$type}{$interface}{$ipaddr}{"vlan"}         = undef;
             $ret->{$type}{$interface}{$ipaddr}{"interface"}    = $interface;
             $ret->{$type}{$interface}{$ipaddr}{"vpn_instance"} = $vpn_instance;
@@ -854,7 +796,7 @@ sub device_arp {
         #捕捉数据中心CE系列交换机ARP条目
         elsif ( $cli
             =~ /^(?<ipaddr>(\d{1,3}\.){3}(\d{1,3}))\s+((?<mac>(([0-9a-fA-F]{4}\-){2}[0-9a-fA-F]{4}))\s+)?((?<mac>Incomplete)\s+)?((?<exp_time>\d+)\s+)?((?<type_vlan>(.*?)\s+))?((?<interface>.*?)\s+)?(?<vpn_instance>.*?)$/
-            )
+          )
         {
             #获取解析结果
             my $mac          = $+{mac};
@@ -870,15 +812,12 @@ sub device_arp {
             if ( $mac =~ /Incomplete/i ) {
 
                 #封装特定的数据结构
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"ipaddr"} = $ipaddr;
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"mac"} = "Incomplete";
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"exp_time"}
-                    = $exp_time || "forever";
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"vlan"} = $vlan;
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"interface"}
-                    = $interface;
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"vpn_instance"}
-                    = $vpn_instance;
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"ipaddr"}       = $ipaddr;
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"mac"}          = "Incomplete";
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"exp_time"}     = $exp_time || "forever";
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"vlan"}         = $vlan;
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"interface"}    = $interface;
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"vpn_instance"} = $vpn_instance;
 
                 #继续下一个迭代
                 next;
@@ -901,10 +840,9 @@ sub device_arp {
             next if $type eq "dynamic" && $interface =~ /MEth/i;
 
             #输出解析结果
-            $ret->{$type}{$interface}{$ipaddr}{"ipaddr"} = $ipaddr;
-            $ret->{$type}{$interface}{$ipaddr}{"mac"}    = $mac;
-            $ret->{$type}{$interface}{$ipaddr}{"exp_time"}
-                = $exp_time || "forever";
+            $ret->{$type}{$interface}{$ipaddr}{"ipaddr"}       = $ipaddr;
+            $ret->{$type}{$interface}{$ipaddr}{"mac"}          = $mac;
+            $ret->{$type}{$interface}{$ipaddr}{"exp_time"}     = $exp_time || "forever";
             $ret->{$type}{$interface}{$ipaddr}{"vlan"}         = $vlan;
             $ret->{$type}{$interface}{$ipaddr}{"interface"}    = $interface;
             $ret->{$type}{$interface}{$ipaddr}{"vpn_instance"} = $vpn_instance;
@@ -1003,8 +941,7 @@ sub device_nei {
         if ( $ce6855_later && $cli =~ /eSpace|GE/ ) {
 
             #截取相关字段
-            my ( $src_int, $exp_time, $dst_int, $neighbor )
-                = split( /\s+/, $cli );
+            my ( $src_int, $exp_time, $dst_int, $neighbor ) = split( /\s+/, $cli );
 
             #设置跳转逻辑
             #next if $dst_int =~ $mac_str;
@@ -1018,8 +955,7 @@ sub device_nei {
         elsif ( $ce6855_before && $cli =~ /eSpace|GE/ ) {
 
             #截取相关字段
-            my ( $src_int, $neighbor, $dst_int, $exp_time )
-                = split( /\s+/, $cli );
+            my ( $src_int, $neighbor, $dst_int, $exp_time ) = split( /\s+/, $cli );
 
             #设置跳转逻辑
             #next if $dst_int =~ $mac_str;
